@@ -17,21 +17,15 @@ sub _objectify {
 
 sub _children {
     my $self = shift;
-    my $path =  shift;
-    return map { [ $_->basename, $_ ] } $path->children
+    my $path = shift;
+    return map { [ $_->basename, $_ ] } $path->children;
 }
 
 sub _defaults {
-    return (
-        $_[0]->SUPER::_defaults,
-        _stringify => 0,
-    );
+    return ( $_[0]->SUPER::_defaults, _stringify => 0, );
 }
 
 sub _fast_defaults {
-    return (
-        $_[0]->SUPER::_fast_defaults,
-        _stringify => 0,
-    );
+    return ( $_[0]->SUPER::_fast_defaults, _stringify => 0, );
 }
 
